==> ogre-next-2.3.3-1-x86_64.pkg.tar.zst: usr/share/OGRE-Next/docs/api/html/search/defines_3.js <==
var searchData=
[
  ['d3d9_5fdevice_5faccess_5fcritical_5fsection_0',['D3D9_DEVICE_ACCESS_CRITICAL_SECTION',['../_ogre_d3_d9_prerequisites_8h.html#ac3bbc540f840085496c5f93d9a67c01a',1,'OgreD3D9Prerequisites.h']]],
  ['d3d9_5fdevice_5faccess_5flock_1',['D3D9_DEVICE_ACCESS_LOCK',['../_ogre_d3_d9_prerequisites_8h.html#a2e3011f13cee6773488e8b9fb23527d6',1,'OgreD3D9Prerequisites.h']]],
  ['d3d9_5fdevice_5faccess_5funlock_2',['D3D9_DEVICE_ACCESS_UNLOCK',['../_ogre_d3_d9_prerequisites_8h.html#abe7c6aa3317ab4ec310693df0c476f80',1,'OgreD3D9Prerequisites.h']]],
  ['d3dcolorvalue_5fdefined_3',['D3DCOLORVALUE_DEFINED',['../_ogre_d3_d11_legacy_s_d_k_emulation_8h.html#ad9882dce35433d8334e54fcb176f231e',1,'OgreD3D11LegacySDKEmulation.h']]],
  ['debug_5f_4',['DEBUG_',['../_ogre_g_l_e_s2_prerequisites_8h.html#a45bbdef2e602a1d12b999a837df8fb89',1,'OgreGLES2Prerequisites.h']]],
  ['decl_5fmalloc_5',['DECL_MALLOC',['../_ogre_platform_8h.html#aa1730b3ff27777dab53a340f23844db4',1,'OgrePlatform.h']]],
  ['defining_5fvk_5fsupport_5fimpl_6',['defining_vk_support_impl',['../_ogre_vulkan_android_support_8h.html#a687c4460355e5b2230b2ac9715ede6a0',1,'DEFINING_VK_SUPPORT_IMPL:&#160;OgreVulkanAndroidSupport.h'],['../_ogre_vulkan_win32_support_8h.html#a687c4460355e5b2230b2ac9715ede6a0',1,'DEFINING_VK_SUPPORT_IMPL:&#160;OgreVulkanWin32Support.h'],['../_ogre_vulkan_xcb_support_8h.html#a687c4460355e5b2230b2ac9715ede6a0',1,'DEFINING_VK_SUPPORT_IMPL:&#160;OgreVulkanXcbSupport.h']]],
  ['direct3d_5fversion_7',['DIRECT3D_VERSION',['../_ogre_d3_d9_prerequisites_8h.html#aa54da3d73d29cce6595914535d88a09a',1,'OgreD3D9Prerequisites.h']]],
  ['dxgi_5fswap_5feffect_5fflip_5fdiscard_8',['DXGI_SWAP_EFFECT_FLIP_DISCARD',['../_ogre_d3_d11_legacy_s_d_k_emulation_8h.html#a4a659f0dfa90739fbc72700f3efbdc19',1,'OgreD3D11LegacySDKEmulation.h']]],
  ['dxgi_5fswap_5feffect_5fflip_5fsequential_9',['DXGI_SWAP_EFFECT_FLIP_SEQUENTIAL',['../_ogre_d3_d11_legacy_s_d_k_emulation_8h.html#a1b91409ee211c5c4b62b7b4e045e00e0',1,'OgreD3D11LegacySDKEmulation.h']]]
];

==> ogre-next-2.3.3-3-x86_64.pkg.tar.zst: usr/share/OGRE-Next/docs/api/html/search/defines_3.js <==
var searchData=
[
  ['d3d9_5fdevice_5faccess_5fcritical_5fsection_0',['D3D9_DEVICE_ACCESS_CRITICAL_SECTION',['../_ogre_d3_d9_prerequisites_8h.html#ac3bbc540f840085496c5f93d9a67c01a',1,'OgreD3D9Prerequisites.h']]],
  ['d3d9_5fdevice_5faccess_5flock_1',['D3D9_DEVICE_ACCESS_LOCK',['../_ogre_d3_d9_prerequisites_8h.html#a2e3011f13cee6773488e8b9fb23527d6',1,'OgreD3D9Prerequisites.h']]],
  ['d3d9_5fdevice_5faccess_5funlock_2',['D3D9_DEVICE_ACCESS_UNLOCK',['../_ogre_d3_d9_prerequisites_8h.html#abe7c6aa3317ab4ec310693df0c476f80',1,'OgreD3D9Prerequisites.h']]],
  ['d3dcolorvalue_5fdefined_3',['D3DCOLORVALUE_DEFINED',['../_ogre_d3_d11_legacy_s_d_k_emulation_8h.html#ad9882dce35433d8334e54fcb176f231e',1,'OgreD3D11LegacySDKEmulation.h']]],
  ['debug_5f_4',['DEBUG_',['../_ogre_g_l_e_s2_prerequisites_8h.html#a45bbdef2e602a1d12b999a837df8fb89',1,'OgreGLES2Prerequisites.h']]],
  ['decl_5fmalloc_5',['DECL_MALLOC',['../_ogre_platform_8h.html#aa1730b3ff27777dab53a340f23844db4',1,'OgrePlatform.h']]],
  ['defining_5fvk_5fsupport_5fimpl_6',['DEFINING_VK_SUPPORT_IMPL',['../_ogre_vulkan_android_support_8h.html#a687c4460355e5b2230b2ac9715ede6a0',1,'DEFINING_VK_SUPPORT_IMPL:&#160;OgreVulkanAndroidSupport.h'],['../_ogre_vulkan_win32_support_8h.html#a687c4460355e5b2230b2ac9715ede6a0',1,'DEFINING_VK_SUPPORT_IMPL:&#160;OgreVulkanWin32Support.h'],['../_ogre_vulkan_xcb_support_8h.html#a687c4460355e5b2230b2ac9715ede6a0',1,'DEFINING_VK_SUPPORT_IMPL:&#160;OgreVulkanXcbSupport.h']]],
  ['direct3d_5fversion_7',['DIRECT3D_VERSION',['../_ogre_d3_d9_prerequisites_8h.html#aa54da3d73d29cce6595914535d88a09a',1,'OgreD3D9Prerequisites.h']]],
  ['dxgi_5fswap_5feffect_5fflip_5fdiscard_8',['DXGI_SWAP_EFFECT_FLIP_DISCARD',['../_ogre_d3_d11_legacy_s_d_k_emulation_8h.html#a4a659f0dfa90739fbc72700f3efbdc19',1,'OgreD3D11LegacySDKEmulation.h']]],
  ['dxgi_5fswap_5feffect_5fflip_5fsequential_9',['DXGI_SWAP_EFFECT_FLIP_SEQUENTIAL',['../_ogre_d3_d11_legacy_s_d_k_emulation_8h.html#a1b91409ee211c5c4b62b7b4e045e00e0',1,'OgreD3D11LegacySDKEmulation.h']]]
];
